@@ -10,20 +10,12 @@
 
 #include "metkit/mars/MarsParsedRequest.h"
 
+namespace metkit::mars {
 
-namespace metkit {
-namespace mars {
-
-//----------------------------------------------------------------------------------------------------------------------
-
-
-MarsParsedRequest::MarsParsedRequest(const std::string& verb,
-                                     size_t line,
-                                     size_t column):
-    MarsRequest(verb),
-    MarsParserContext(line, column) {
+MarsParsedRequest::MarsParsedRequest(const std::string& verb, size_t line) : MarsRequest(verb), line_(line) {}
 
+void MarsParsedRequest::info(std::ostream& out) const {
+    out << " Request starting line " << line_;
 }
 
-} // namespace mars
-} // namespace metkit
+}  // namespace metkit::mars
