@@ -25,24 +25,23 @@ namespace mars {
 
 class TypeMixed : public Type {
 
-public: // methods
+public:  // methods
 
-    TypeMixed(const std::string &name, const eckit::Value& settings);
+    TypeMixed(const std::string& name, const eckit::Value& settings);
 
-    virtual ~TypeMixed();
+    ~TypeMixed() noexcept override;
 
-private: // methods
+private:  // methods
 
-    virtual void print( std::ostream &out ) const;
-    virtual bool expand(const MarsExpandContext& ctx, std::string& value) const ;
-
-    std::vector<Type*> types_;
+    void print(std::ostream& out) const override;
+    bool expand(std::string& value, const MarsRequest& request) const override;
 
+    std::vector<std::pair<std::unique_ptr<Context>, Type*>> types_;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace mars
-} // namespace metkit
+}  // namespace mars
+}  // namespace metkit
 
 #endif
