@@ -13,42 +13,33 @@
 /// @author Tiago Quintino
 /// @date   April 2016
 
-#ifndef metkit_TypeParam_H
-#define metkit_TypeParam_H
+#pragma once
 
 #include "metkit/mars/Type.h"
 
-namespace metkit {
-namespace mars {
+namespace metkit::mars {
 
 //----------------------------------------------------------------------------------------------------------------------
 
 class TypeParam : public Type {
 
-public: // methods
+public:  // methods
 
-    TypeParam(const std::string &name, const eckit::Value& settings);
+    TypeParam(const std::string& name, const eckit::Value& settings);
 
-    virtual ~TypeParam();
+    ~TypeParam() noexcept override = default;
 
-protected:
-    virtual bool expand(const MarsExpandContext& ctx, const MarsRequest& request, std::vector<std::string>& values, bool fail) const;
-
-private: // methods
+private:  // methods
 
     eckit::ValueMap expandWith_;
     bool firstRule_;
 
-    virtual void print(std::ostream &out) const;
-    virtual void reset();
-    virtual void pass2(const MarsExpandContext& ctx, MarsRequest& request);
-    virtual void expand(const MarsExpandContext& ctx, std::vector<std::string>& values) const;
-
+    void print(std::ostream& out) const override;
+    void reset() override;
+    void pass2(MarsRequest& request) override;
+    bool expand(std::string& value, const MarsRequest& request) const override;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace mars
-} // namespace metkit
-
-#endif
+}  // namespace metkit::mars
