@@ -11,6 +11,7 @@
 /// @file   TypeTime.h
 /// @author Baudouin Raoult
 /// @author Tiago Quintino
+/// @author Emanuele Danovaro
 /// @date   April 2016
 
 #ifndef metkit_TypeTime_H
@@ -18,33 +19,26 @@
 
 #include "metkit/mars/Type.h"
 
-namespace metkit {
-namespace mars {
+namespace metkit::mars {
 
 //----------------------------------------------------------------------------------------------------------------------
 
 class TypeTime : public Type {
 
-public: // methods
+public:  // methods
 
-    TypeTime(const std::string &name, const eckit::Value& settings);
+    TypeTime(const std::string& name, const eckit::Value& settings);
 
-    virtual ~TypeTime();
+    ~TypeTime() noexcept override = default;
 
+private:  // methods
 
-private: // methods
-
-    virtual void print( std::ostream &out ) const;
-    virtual void expand(const MarsExpandContext& ctx, std::vector<std::string>& values) const;
-    virtual bool expand(const MarsExpandContext& ctx, std::string& value) const ;
-
-    long by_;
-
+    void print(std::ostream& out) const override;
+    bool expand(std::string& value, const MarsRequest& request) const override;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace mars
-} // namespace metkit
+}  // namespace metkit::mars
 
 #endif
